@@ -97,6 +97,9 @@ validate_idata <- function(idata) {
 ##' \item \code{tad} logical; when \code{TRUE} a column is added to simulated output is added showing the 
 ##' time since the last dose.  Only data records with \code{evid == 1} will be considered doses for the 
 ##' purposes of \code{tad} calculation.
+##' \item \code{nocb} if \code{TRUE} (default), time-varying items in a data set will be
+##' implemented as next observation carried back; if \code{FALSE} time-varying items
+##' in a data set will be implemented as last observation carried forward.  
 ##' }
 ##' @details
 ##' \itemize{
@@ -254,6 +257,7 @@ tran_mrgsim <- function(x,
                         filbak=TRUE,
                         t2advance = FALSE,
                         tad = FALSE,
+                        nocb = TRUE,
                         ...) {
   
   verbose <- x@verbose
@@ -354,6 +358,7 @@ tran_mrgsim <- function(x,
   parin$ptimes <- stime(ptime)
   parin$filbak <- filbak
   parin$tad <- tad
+  parin$nocb <- nocb
   
   if(any(x@capture =="tad") & tad) {
     stop("tad argument is true and 'tad' found in $CAPTURE",call.=FALSE); 
