@@ -82,13 +82,9 @@ render_time <- function(x) {
 ##' @export
 mvgauss <- function(mat, n=10, seed=NULL) {
   if(!is.null(seed)) set.seed(seed)
-  .Call(mrgsolve_MVGAUSS, mat, n)
+  .Call(`_mrgsolve_MVGAUSS`, mat, n)
 }
 
-# simulateres <- function(n1,omega,n2,sigma) {
-#   .Call("mrgsolve_SIMRE", PACKAGE="mrgsolve", n1, omega,n2,sigma,-1)
-# }
-
 
 pfile <- function(package,dir,file,ext=NULL) {
   ans <- file.path(path.package(package),dir,file)
@@ -327,8 +323,8 @@ as_character_args <- function(x) {
 
 get_tokens <- function(x,unlist=FALSE) {
   if(!is.character(x)) return(character(0))
-  if(unlist) return(.Call(mrgsolve_get_tokens, x)[["tokens"]])
-  .Call(mrgsolve_get_tokens, x)
+  if(unlist) return(.Call(`_mrgsolve_get_tokens`, x)[["tokens"]])
+  .Call(`_mrgsolve_get_tokens`, x)
 }
 
 grepn <- function(x,pat,warn=FALSE) {
@@ -511,6 +507,10 @@ build_error <- function(args,compfile) {
   stop("there was a problem building the model.",call.=FALSE)
 }
 
+na2zero <- function(x) {
+  x[is.na(x)] <- 0
+  x
+}
 
 # covset <- function(...) {
 #   dmutate::covset(...)
